@@ -68,9 +68,9 @@ stata_engine <- function (options)
     stop(paste(out, collapse = "\n"))
   if (!all(options$eval==FALSE) && options$engine == "stata" && file.exists(logf))
     out = c(readLines(logf), out)
-#  stataengine_output(options, options$code, out)
 # print("log file read")
 # print(out)
+# print(engine_output)
 # print(knitr::engine_output)
-  knitr::engine_output(options, options$code, out)
+  engine_output(options, options$code, out)
 }
